==> mediawiki-1.15.5.tbz: www/mediawiki/languages/messages/MessagesLez.php <==
<?php
/** Lezghian (Лезги)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Amikeco
 */

$messages = array(
# Dates
'monday'        => 'Ислен',
'sun'           => 'Гья',
'mon'           => 'Исл',
'tue'           => 'Сал',
'wed'           => 'Aрб',
'thu'           => 'Xем',
'fri'           => 'Жум',
'sat'           => 'Киш',
'january'       => 'Гьер',
'february'      => 'Эхем',
'march'         => 'Ибне',
'april'         => 'Нава',
'may_long'      => 'ТӀул',
'june'          => 'Къамуг',
'july'          => 'Чиле',
'august'        => 'Пахун',
'september'     => 'Мара',
'october'       => 'БаскӀум',
'november'      => 'ЦӀехуьл',
'december'      => 'ФaндукӀ',
'january-gen'   => 'Гьер',
'february-gen'  => 'Эхем',
'march-gen'     => 'Ибне',
'april-gen'     => 'Нава',
'may-gen'       => 'ТӀул',
'june-gen'      => 'Къамуг',
'july-gen'      => 'Чиле',
'august-gen'    => 'Пахун',
'september-gen' => 'Мара',
'october-gen'   => 'БаскӀум',
'november-gen'  => 'ЦӀехуьл',
'december-gen'  => 'ФaндукӀ',
'jan'           => 'Гье',
'feb'           => 'Эхе',
'mar'           => 'Ибн',
'apr'           => 'Нав',
'may'           => 'ТӀу',
'jun'           => 'Къа',
'jul'           => 'Чил',
'aug'           => 'Пахун',
'sep'           => 'Мар',
'oct'           => 'Бас',
'nov'           => 'ЦӀе',
'dec'           => 'Фaн',

'about'  => 'Хакъиндай',
'qbfind' => 'Жугъун',
'qbedit' => 'Дегишарун',

'errorpagetitle'   => 'ГъалатI',
'returnto'         => 'Хкун $1.',
'help'             => 'Чара',
'search'           => 'Ахтармишун',
'searchbutton'     => 'Ахтармишун',
'searcharticle'    => 'Фин',
'history'          => 'Хъувун тарих',
'history_short'    => 'Тарих',
'edit'             => 'Дегишарун',
'delete'           => 'Къакъудун',
'deletethispage'   => 'Къакъудун и хъувун',
'protect'          => 'Xуьн',
'protectthispage'  => 'Xуьн и хъувун',
'newpage'          => 'ЦIийи хъувун',
'talkpagelinktext' => 'Рахун',
'personaltools'    => 'Инсан aлат',
'talk'             => 'Рахун',
'toolbox'          => 'Aлаткъаб',
'jumpto'           => 'Къудгъунун:',
'jumptosearch'     => 'ахтармишун',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'    => 'Хакъиндай {{SITENAME}}',
'aboutpage'    => 'Project:Хакъиндай',
'edithelp'     => 'Дегишарун чара',
'edithelppage' => 'Help:Дегишарун',
'mainpage'     => 'Асул хъувун',

'youhavenewmessages' => 'Вунз ава $1 ($2).',
'editsection'        => 'дегишарун',
'editold'            => 'дегишарун',
'editsectionhint'    => 'Дегишарун пай: $1',
'showtoc'            => 'къаларун',
'hidetoc'            => 'чуьнуьхун',
'site-rss-feed'      => '$1 РСС Xуьрек',
'site-atom-feed'     => '$1 Атом Xуьрек',
'page-rss-feed'      => '"$1" РСС Xуьрек',
'page-atom-feed'     => '"$1" Атом Xуьрек',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Хъувун',
'nstab-special'   => 'КьетIен',
'nstab-image'     => 'Шикил',
'nstab-mediawiki' => 'Меслят',

# General errors
'viewsource' => 'Къаларун булах',

# Login and logout pages
'yourrealname' => 'Xалис тIвар:',

# Edit pages
'minoredit'      => 'И гъвечIи дегишарун',
'watchthis'      => 'Гелкъуьн и хъувун',
'showdiff'       => 'Къаларун дегишарун',
'newarticle'     => '(ЦIийи)',
'editing'        => 'Дегишарун $1',
'editingsection' => 'Дегишарун $1 (пай)',

# History pages
'last'       => 'эхиримжи',
'page_first' => 'сифте',
'page_last'  => 'эхиримжи',

# Diffs
'lineno' => 'ЦIар $1:',

# Search results
'viewprevnext' => 'Къаларун ($1) ($2) ($3)',
'powersearch'  => 'Ахтармишун',

# Recent changes
'diff'            => 'тафават',
'hist'            => 'тарих',
'hide'            => 'Чуьнуьхун',
'show'            => 'Къаларун',
'minoreditletter' => 'г',
'newpageletter'   => 'ЦI',

# Upload
'upload' => 'Парвиниз шикил',

# File description page
'filehist'          => 'Шикил тарих',
'filehist-datetime' => 'Югъ/Заман',

# MIME search
'mimesearch' => 'MIME ахтармишун',

# Miscellaneous special pages
'lonelypages'  => 'Eтим xъувун',
'shortpages'   => 'Куьруь хъувун',
'longpages'    => 'Яргъи хъувун',
'newpages'     => 'ЦIийи хъувун',
'move'         => 'Юзун',
'movethispage' => 'Юзун и хъувун',

# Book sources
'booksources' => 'Ктаб булах',

# Special:AllPages
'allpages'       => 'Вири хъувун',
'allarticles'    => 'Вири хъувун',
'allpagessubmit' => 'Фин',

# Watchlist
'watch'         => 'Гелкъуьн',
'watchthispage' => 'Гелкъуьн и хъувун',

# Delete
'deletepage'            => 'Къакъудун хъувун',
'deletereasonotherlist' => 'Маса фагьум',

# Rollback
'rollbacklink' => 'авахьун далу',

# Protect
'restriction-type' => 'Ихтияр:',

# Namespace form on various pages
'blanknamespace' => '(Асул)',

# Contributions
'uctop' => '(кIукI)',

# Block/unblock
'blocklink' => 'тIаб',

# Move page
'movearticle' => 'Юзун хъувун:',
'move-watch'  => 'Гелкъуьн и хъувун',
'movepagebtn' => 'Юзун хъувун',
'movereason'  => 'Фагьум:',

# Tooltip help for the actions
'tooltip-ca-protect' => 'Xуьн и хъувун',
'tooltip-ca-delete'  => 'Къакъудун и хъувун',
'tooltip-ca-move'    => 'Юзун и хъувун',
'tooltip-search'     => 'Ахтармишун {{SITENAME}}',
'tooltip-t-upload'   => 'Парвиниз шикил',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'вири',
'namespacesall' => 'вири',
'monthsall'     => 'вири',

# Special:SpecialPages
'specialpages' => 'КьетIен хъувун',

);

==> mediawiki-1.16.0.tbz: www/mediawiki/languages/messages/MessagesLez.php <==
<?php
/** Lezghian (Лезги)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Amikeco
 */

$messages = array(
# Dates
'monday'        => 'Ислен',
'sun'           => 'Гья',
'mon'           => 'Исл',
'tue'           => 'Сал',
'wed'           => 'Aрб',
'thu'           => 'Xем',
'fri'           => 'Жум',
'sat'           => 'Киш',
'january'       => 'Гьер',
'february'      => 'Эхем',
'march'         => 'Ибне',
'april'         => 'Нава',
'may_long'      => 'ТӀул',
'june'          => 'Къамуг',
'july'          => 'Чиле',
'august'        => 'Пахун',
'september'     => 'Мара',
'october'       => 'БаскӀум',
'november'      => 'ЦӀехуьл',
'december'      => 'ФaндукӀ',
'january-gen'   => 'Гьер',
'february-gen'  => 'Эхем',
'march-gen'     => 'Ибне',
'april-gen'     => 'Нава',
'may-gen'       => 'ТӀул',
'june-gen'      => 'Къамуг',
'july-gen'      => 'Чиле',
'august-gen'    => 'Пахун',
'september-gen' => 'Мара',
'october-gen'   => 'БаскӀум',
'november-gen'  => 'ЦӀехуьл',
'december-gen'  => 'ФaндукӀ',
'jan'           => 'Гье',
'feb'           => 'Эхе',
'mar'           => 'Ибн',
'apr'           => 'Нав',
'may'           => 'ТӀу',
'jun'           => 'Къа',
'jul'           => 'Чил',
'aug'           => 'Пахун',
'sep'           => 'Мар',
'oct'           => 'Бас',
'nov'           => 'ЦӀе',
'dec'           => 'Фaн',

'about' => 'Хакъиндай',

# Cologne Blue skin
'qbfind' => 'Жугъун',
'qbedit' => 'Дегишарун',

'errorpagetitle'   => 'ГъалатI',
'returnto'         => 'Хкун $1.',
'help'             => 'Чара',
'search'           => 'Ахтармишун',
'searchbutton'     => 'Ахтармишун',
'searcharticle'    => 'Фин',
'history'          => 'Хъувун тарих',
'history_short'    => 'Тарих',
'edit'             => 'Дегишарун',
'delete'           => 'Къакъудун',
'deletethispage'   => 'Къакъудун и хъувун',
'protect'          => 'Xуьн',
'protectthispage'  => 'Xуьн и хъувун',
'newpage'          => 'ЦIийи хъувун',
'talkpagelinktext' => 'Рахун',
'personaltools'    => 'Инсан aлат',
'talk'             => 'Рахун',
'toolbox'          => 'Aлаткъаб',
'jumpto'           => 'Къудгъунун:',
'jumptosearch'     => 'ахтармишун',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'    => 'Хакъиндай {{SITENAME}}',
'aboutpage'    => 'Project:Хакъиндай',
'edithelp'     => 'Дегишарун чара',
'edithelppage' => 'Help:Дегишарун',
'mainpage'     => 'Асул хъувун',

'youhavenewmessages' => 'Вунз ава $1 ($2).',
'editsection'        => 'дегишарун',
'editold'            => 'дегишарун',
'editsectionhint'    => 'Дегишарун пай: $1',
'showtoc'            => 'къаларун',
'hidetoc'            => 'чуьнуьхун',
'site-rss-feed'      => '$1 РСС Xуьрек',
'site-atom-feed'     => '$1 Атом Xуьрек',
'page-rss-feed'      => '"$1" РСС Xуьрек',
'page-atom-feed'     => '"$1" Атом Xуьрек',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Хъувун',
'nstab-special'   => 'КьетIен',
'nstab-image'     => 'Шикил',
'nstab-mediawiki' => 'Меслят',

# General errors
'viewsource' => 'Къаларун булах',

# Edit pages
'minoredit'      => 'И гъвечIи дегишарун',
'watchthis'      => 'Гелкъуьн и хъувун',
'showdiff'       => 'Къаларун дегишарун',
'newarticle'     => '(ЦIийи)',
'editing'        => 'Дегишарун $1',
'editingsection' => 'Дегишарун $1 (пай)',

# History pages
'last'       => 'эхиримжи',
'page_first' => 'сифте',
'page_last'  => 'эхиримжи',

# Diffs
'lineno' => 'ЦIар $1:',

# Search results
'viewprevnext' => 'Къаларун ($1 {{int:pipe-separator}} $2) ($3)',
'powersearch'  => 'Ахтармишун',

# Preferences page
'yourrealname' => 'Xалис тIвар:',

# Recent changes
'diff'            => 'тафават',
'hist'            => 'тарих',
'hide'            => 'Чуьнуьхун',
'show'            => 'Къаларун',
'minoreditletter' => 'г',
'newpageletter'   => 'ЦI',

# Upload
'upload' => 'Парвиниз шикил',

# File description page
'file-anchor-link'  => 'Шикил',
'filehist'          => 'Шикил тарих',
'filehist-datetime' => 'Югъ/Заман',

# MIME search
'mimesearch' => 'MIME ахтармишун',

# Miscellaneous special pages
'lonelypages'  => 'Eтим xъувун',
'shortpages'   => 'Куьруь хъувун',
'longpages'    => 'Яргъи хъувун',
'newpages'     => 'ЦIийи хъувун',
'move'         => 'Юзун',
'movethispage' => 'Юзун и хъувун',

# Book sources
'booksources' => 'Ктаб булах',

# Special:AllPages
'allpages'       => 'Вири хъувун',
'allarticles'    => 'Вири хъувун',
'allpagessubmit' => 'Фин',

# Watchlist
'watch'         => 'Гелкъуьн',
'watchthispage' => 'Гелкъуьн и хъувун',

# Delete
'deletepage'            => 'Къакъудун хъувун',
'deletereasonotherlist' => 'Маса фагьум',

# Rollback
'rollbacklink' => 'авахьун далу',

# Protect
'restriction-type' => 'Ихтияр:',

# Namespace form on various pages
'blanknamespace' => '(Асул)',

# Contributions
'uctop' => '(кIукI)',

'sp-contributions-talk' => 'Рахун',

# Block/unblock
'blocklink' => 'тIаб',

# Move page
'movearticle' => 'Юзун хъувун:',
'move-watch'  => 'Гелкъуьн и хъувун',
'movepagebtn' => 'Юзун хъувун',
'movereason'  => 'Фагьум:',

# Tooltip help for the actions
'tooltip-ca-protect' => 'Xуьн и хъувун',
'tooltip-ca-delete'  => 'Къакъудун и хъувун',
'tooltip-ca-move'    => 'Юзун и хъувун',
'tooltip-search'     => 'Ахтармишун {{SITENAME}}',
'tooltip-t-upload'   => 'Парвиниз шикил',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'вири',
'namespacesall' => 'вири',
'monthsall'     => 'вири',

# Special:SpecialPages
'specialpages' => 'КьетIен хъувун',

);
